aboutsummaryrefslogtreecommitdiffstats
path: root/ethereum/javascript_console.go
diff options
context:
space:
mode:
authorobscuren <geffobscura@gmail.com>2014-05-17 21:15:46 +0800
committerobscuren <geffobscura@gmail.com>2014-05-17 21:15:46 +0800
commit770808ce0d44cadfedbe01694c836be2eaf0e82c (patch)
treef79310a0ea409805897d738f2c2fb7aa5d597355 /ethereum/javascript_console.go
parent2ac292dc7ada20d64188b9d35f23600e4642021b (diff)
downloadgo-tangerine-770808ce0d44cadfedbe01694c836be2eaf0e82c.tar
go-tangerine-770808ce0d44cadfedbe01694c836be2eaf0e82c.tar.gz
go-tangerine-770808ce0d44cadfedbe01694c836be2eaf0e82c.tar.bz2
go-tangerine-770808ce0d44cadfedbe01694c836be2eaf0e82c.tar.lz
go-tangerine-770808ce0d44cadfedbe01694c836be2eaf0e82c.tar.xz
go-tangerine-770808ce0d44cadfedbe01694c836be2eaf0e82c.tar.zst
go-tangerine-770808ce0d44cadfedbe01694c836be2eaf0e82c.zip
Readline repl for linux & osx
Diffstat (limited to 'ethereum/javascript_console.go')
-rw-r--r--ethereum/javascript_console.go71
1 files changed, 38 insertions, 33 deletions
diff --git a/ethereum/javascript_console.go b/ethereum/javascript_console.go
index 9adf51bcc..9a10ca236 100644
--- a/ethereum/javascript_console.go
+++ b/ethereum/javascript_console.go
@@ -1,47 +1,58 @@
package main
import (
- "bufio"
"fmt"
"github.com/ethereum/eth-go"
"github.com/ethereum/eth-go/ethpub"
"github.com/robertkrimen/otto"
- "os"
)
-type JSConsole struct {
+type Repl interface {
+ Start()
+}
+
+type JSRE struct {
vm *otto.Otto
lib *ethpub.PEthereum
}
-func NewJSConsole(ethereum *eth.Ethereum) *JSConsole {
- return &JSConsole{vm: otto.New(), lib: ethpub.NewPEthereum(ethereum)}
+func NewJSRE(ethereum *eth.Ethereum) *JSRE {
+ re := &JSRE{vm: otto.New(), lib: ethpub.NewPEthereum(ethereum)}
+
+ re.Bind("eth", &JSEthereum{re.lib, re.vm})
+
+ return re
+}
+
+func (self *JSRE) Bind(name string, v interface{}) {
+ self.vm.Set(name, v)
+}
+
+func (self *JSRE) Run(code string) (otto.Value, error) {
+ return self.vm.Run(code)
}
-func (self *JSConsole) Start() {
- self.initBindings()
+type JSRepl struct {
+ re *JSRE
+}
+
+func NewJSRepl(ethereum *eth.Ethereum) *JSRepl {
+ return &JSRepl{re: NewJSRE(ethereum)}
+}
+func (self *JSRepl) Start() {
fmt.Println("Eth JavaScript console")
- reader := bufio.NewReader(os.Stdin)
- for {
- fmt.Printf("eth >>> ")
- str, _, err := reader.ReadLine()
- if err != nil {
- fmt.Println("Error reading input", err)
- } else {
- self.ParseInput(string(str))
- }
- }
+ self.read()
}
-func (self *JSConsole) ParseInput(code string) {
+func (self *JSRepl) parseInput(code string) {
defer func() {
if r := recover(); r != nil {
fmt.Println("[native] error", r)
}
}()
- value, err := self.vm.Run(code)
+ value, err := self.re.Run(code)
if err != nil {
fmt.Println(err)
return
@@ -50,28 +61,22 @@ func (self *JSConsole) ParseInput(code string) {
fmt.Println(value)
}
-func (self *JSConsole) initBindings() {
- t := &JSWrapper{self.lib, self.vm}
-
- self.vm.Set("eth", t)
-}
-
-// The JS wrapper attempts to wrap the PEthereum object and returns
-// proper javascript objects
-type JSWrapper struct {
+// The JSEthereum object attempts to wrap the PEthereum object and returns
+// meaningful javascript objects
+type JSEthereum struct {
*ethpub.PEthereum
vm *otto.Otto
}
-func (self *JSWrapper) GetKey() otto.Value {
+func (self *JSEthereum) GetKey() otto.Value {
return self.toVal(self.PEthereum.GetKey())
}
-func (self *JSWrapper) GetStateObject(addr string) otto.Value {
+func (self *JSEthereum) GetStateObject(addr string) otto.Value {
return self.toVal(self.PEthereum.GetStateObject(addr))
}
-func (self *JSWrapper) Transact(key, recipient, valueStr, gasStr, gasPriceStr, dataStr string) otto.Value {
+func (self *JSEthereum) Transact(key, recipient, valueStr, gasStr, gasPriceStr, dataStr string) otto.Value {
r, err := self.PEthereum.Transact(key, recipient, valueStr, gasStr, gasPriceStr, dataStr)
if err != nil {
fmt.Println(err)
@@ -82,7 +87,7 @@ func (self *JSWrapper) Transact(key, recipient, valueStr, gasStr, gasPriceStr, d
return self.toVal(r)
}
-func (self *JSWrapper) Create(key, valueStr, gasStr, gasPriceStr, initStr, bodyStr string) otto.Value {
+func (self *JSEthereum) Create(key, valueStr, gasStr, gasPriceStr, initStr, bodyStr string) otto.Value {
r, err := self.PEthereum.Create(key, valueStr, gasStr, gasPriceStr, initStr, bodyStr)
if err != nil {
@@ -95,7 +100,7 @@ func (self *JSWrapper) Create(key, valueStr, gasStr, gasPriceStr, initStr, bodyS
}
// Wrapper function
-func (self *JSWrapper) toVal(v interface{}) otto.Value {
+func (self *JSEthereum) toVal(v interface{}) otto.Value {
result, err := self.vm.ToValue(v)
if err != nil {